# CR Learn

A Library Provides  datasets to speed up your recsys learing.

## Installation

```bash
pip install cr_learn
```

## Usage

```python
from cr_learn.ml_1m import load
from cr_learn.beibei import load
etc
```

# Dataset List

| Dataset Name    | Description           | Available in cr_learn |
|-----------------|-----------------------|------------------------|
| ml-1m           | MovieLens 1M dataset  | ✅                     |
| beibei          | Beibei dataset        | ✅                     |
| tmall           | Tmall dataset         | ✅                     |
| yelp            | Yelp dataset          | ❌                     |
| icjai           | ICJAI dataset         | ✅                     |
| amazon          | Amazon dataset        | ❌                     |
| lastfm          | Last.fm dataset       | ❌                     |
| yahoo           | Yahoo dataset         | ❌                     |
| library_things  | LibraryThings dataset | ✅                     |



